==> igniteui-react-charts-18.1.0.tgz: package/esm5/lib/igr-standard-deviation-indicator.js <==
import { __extends } from "tslib";
import { IgrStrategyBasedIndicator } from "./igr-strategy-based-indicator";
import { StandardDeviationIndicator } from "./StandardDeviationIndicator";
/**
 * Represents a IgxDataChartComponent Standard Deviation indicator series.
 * Default required members: High, Low, Close
*
* `IgrStandardDeviationIndicator` (SDI) measures statistical variation in stock prices or volatility. The difference between an individual security’s closing price and the average security closing price is called the dispersion. The larger the dispersion is the higher the standard deviation will be and therefore the volatility. The smaller the dispersion is (the difference between an individual closing price and the average price), the smaller the standard deviation and the lower the price volatility.
*
* Using this indicator requires setting both the `HighMemberPath`, `LowMemberPath` and `CloseMemberPath`.
*
* ```ts
* <IgrDataChart
*     dataSource={this.state.dataSource}
*     width="700px"
*     height="500px">
*
*     <IgrCategoryXAxis name="xAxis" label="Year" />
*     <IgrNumericYAxis  name="yAxis" />
*
*     <IgrStandardDeviationIndicator
*         name="series1"
*         xAxisName="xAxis"
*         yAxisName="yAxis"
* 		closeMemberPath="Close"
*         highMemberPath="High"
*         lowMemberPath="Low" />
*  </IgrDataChart>
* ```
*
* ```ts
* let series = new IgrStandardDeviationIndicator({name:"series"});
* series.xAxis = this.xAxis;
* series.yAxis = this.yAxis;
* series.closeMemberPath="Close";
* series.highMemberPath="High";
* series.lowMemberPath="Low";
* ```
*/
var IgrStandardDeviationIndicator = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(IgrStandardDeviationIndicator, _super);
    function IgrStandardDeviationIndicator(props) {
        return _super.call(this, props) || this;
    }
    IgrStandardDeviationIndicator.prototype.createImplementation = function () {
        return new StandardDeviationIndicator();
    };
    Object.defineProperty(IgrStandardDeviationIndicator.prototype, "i", {
        /**
                                     * @hidden
                                     */
        get: function () {
            return this._implementation;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrStandardDeviationIndicator.prototype, "period", {
        /**
         * Gets or sets the moving average period for the current StandardDeviationIndicator object.
         * The typical, and initial, value for STDEV periods is 20.
        */
        get: function () {
            return this.i.u6;
        },
        set: function (v) {
            this.i.u6 = +v;
        },
        enumerable: false,
        configurable: true
    });
    return IgrStandardDeviationIndicator;
}(IgrStrategyBasedIndicator));
export { IgrStandardDeviationIndicator };

==> igniteui-react-charts-18.2.0.tgz: package/esm5/lib/igr-standard-deviation-indicator.js <==
import { __extends } from "tslib";
import { IgrStrategyBasedIndicator } from "./igr-strategy-based-indicator";
import { StandardDeviationIndicator } from "./StandardDeviationIndicator";
/**
 * Represents a IgxDataChartComponent Standard Deviation indicator series.
 * Default required members: High, Low, Close
*
* `StandardDeviationIndicator` (SDI) measures statistical variation in stock prices or volatility. The difference between an individual security’s closing price and the average security closing price is called the dispersion. The larger the dispersion is the higher the standard deviation will be and therefore the volatility. The smaller the dispersion is (the difference between an individual closing price and the average price), the smaller the standard deviation and the lower the price volatility.
*
* Using this indicator requires setting both the `HighMemberPath`, `LowMemberPath` and `CloseMemberPath`.
*
* ```ts
* <IgrDataChart
*     dataSource={this.state.dataSource}
*     width="700px"
*     height="500px">
*
*     <IgrCategoryXAxis name="xAxis" label="Year" />
*     <IgrNumericYAxis  name="yAxis" />
*
*     <IgrStandardDeviationIndicator
*         name="series1"
*         xAxisName="xAxis"
*         yAxisName="yAxis"
* 		closeMemberPath="Close"
*         highMemberPath="High"
*         lowMemberPath="Low" />
*  </IgrDataChart>
* ```
*
* ```ts
* let series = new IgrStandardDeviationIndicator({name:"series"});
* series.xAxis = this.xAxis;
* series.yAxis = this.yAxis;
* series.closeMemberPath="Close";
* series.highMemberPath="High";
* series.lowMemberPath="Low";
* ```
*/
var IgrStandardDeviationIndicator = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(IgrStandardDeviationIndicator, _super);
    function IgrStandardDeviationIndicator(props) {
        return _super.call(this, props) || this;
    }
    IgrStandardDeviationIndicator.prototype.createImplementation = function () {
        return new StandardDeviationIndicator();
    };
    Object.defineProperty(IgrStandardDeviationIndicator.prototype, "i", {
        /**
                                     * @hidden
                                     */
        get: function () {
            return this._implementation;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrStandardDeviationIndicator.prototype, "period", {
        /**
         * Gets or sets the moving average period for the current StandardDeviationIndicator object.
         * The typical, and initial, value for STDEV periods is 20.
        */
        get: function () {
            return this.i.va;
        },
        set: function (v) {
            this.i.va = +v;
        },
        enumerable: false,
        configurable: true
    });
    return IgrStandardDeviationIndicator;
}(IgrStrategyBasedIndicator));
export { IgrStandardDeviationIndicator };
